@@ -8,13 +8,15 @@ these are not really related, formatting could be factored out as
 a separate base
 """
 
-from typing import Any, Dict, Optional, List, Union  # NOQA
 import copy
 
 from collections import MutableSet, Sized, Set
 
 from ruamel.yaml.compat import ordereddict, PY2
 
+if False:  # MYPY
+    from typing import Any, Dict, Optional, List, Union  # NOQA
+
 __all__ = ["CommentedSeq", "CommentedKeySeq",
            "CommentedMap", "CommentedOrderedMap",
            "CommentedSet", 'comment_attrib', 'merge_attrib']
@@ -426,7 +428,7 @@ class CommentedSeq(list, CommentedBase):
 
     def __deepcopy__(self, memo):
         # type: (Any) -> Any
-        res = CommentedSeq()
+        res = self.__class__()
         memo[id(self)] = res
         for k in self:
             res.append(copy.deepcopy(k))
@@ -859,7 +861,7 @@ class CommentedMap(ordereddict, CommentedBase):
 
     def __deepcopy__(self, memo):
         # type: (Any) -> Any
-        res = CommentedMap()
+        res = self.__class__()
         memo[id(self)] = res
         for k in self:
             res[k] = copy.deepcopy(self[k])
